<p align="center">
  <strong>
    <a href="https://vector.dev">Website<a/>&nbsp;&nbsp;&bull;&nbsp;&nbsp;<a href="https://vector.dev/docs/">Docs<a/>&nbsp;&nbsp;&bull;&nbsp;&nbsp;<a href="https://vector.dev/community">Community<a/>&nbsp;&nbsp;&bull;&nbsp;&nbsp;<a href="https://github.com/timberio/vector">Github<a/>
  </strong>
</p>

---

<p align="center">
  <img src="https://res.cloudinary.com/timber/image/upload/v1561214425/vector_diagram_w26yw3.svg" alt="Vector">
</p>

Vector is an [open-source][urls.vector_repo] utility for building observability
pipelines. [Collect][docs.sources], [transform][docs.transforms], and
[route][docs.sinks] log, metrics and events with one simple tool.

Built in [Rust][urls.rust], Vector places high-value on
[performance][pages.index#performance], [correctness][pages.index#correctness],
and [operator friendliness][docs.administration]. It compiles to a single static
binary and is designed to be [deployed][docs.deployment] across your entire
infrastructure, serving both as a light-weight [agent][docs.roles.agent] and a
highly efficient [service][docs.roles.service]. Take back ownership and control
of your observability data with Vector.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     distribution/docker/README.md.erb
-->

## Running

```bash
docker run timberio/vector:0.7.2-alpine
```

* The `vector` binary is located at `/usr/local/bin/vector`, which should be in your `$PATH`.
* The default [configuration file][docs.configuration] is located at `/etc/vector/vector.toml`.

## Configuring

The Vector Docker images ship with a [default `/etc/vector/vector.toml` configuration file][urls.default_configuration].
To use your own configuration file:

1. Create your own [Vector configuration file][docs.configuration] and save it
   as `vector.toml`.

2. Run the Vector Docker image with the following command:

   ```bash
   docker run \
    -v $PWD/vector.toml:/etc/vector/vector.toml:ro \
    timberio/vector:0.7.2-alpine
   ```

   Modify `$PWD` to the directory where you store your local `vector.toml` file.

## Image Variants

### alpine

This image is based on the [`alpine` Docker image][urls.docker_alpine], which is
a Linux distribution built around musl libc and BusyBox. It is considerably
smaller in size than other Docker images and statically links libraries. This
is the image we recommend due to it's small size and reliability.

```bash
docker run timberio/vector:0.7.2-alpine
```

### debian

This image is based on the [`debian-slim` image][urls.docker_debian],
which is a smaller, more compact variant of the [`debian` image][urls.docker_debian].

```bash
docker run timberio/vector:0.7.2-debian
```

## Versions

### Latest Version

Vector's Docker images include a special `latest` version that will be updated
whenever Vector is [released][urls.vector_releases]:

```bash
docker run timberio/vector:latest-alpine
```

### Previous Versions

Previous versions can be accessed by their direct tag:

```bash
docker run timberio/vector:<X.X.X>-alpine
```

### Nightlies

Vector's releases nightly versions that contain the latest changes.

```bash
docker run timberio/vector:nightly-alpine
```

Historical nightly versions are also available:

```bash
docker run timberio/vector:nightly-<YYYY-MM-DD>-alpine
```

## Updating

Simply run with newer version in the tag:

```bash
docker run timberio/vector:X.X.X-alpine
```

Or pull the newest latest version:

```bash
docker pull timberio/vector:latest-alpine && \
  docker run timberio/vector:latest-alpine
```

Or run with newer nightly date in the tag:

```bash
docker run timberio/vector:nightly-<YYYY-MM-DD>-alpine
```

Or pull the newest nightly version:

```bash
docker pull timberio/vector:nightly-alpine && \
  docker run timberio/vector:nightly-alpine
```

## Source Files

Vector's Docker source files are located [in it's Github repo][urls.vector_docker_source_files].


[docs.administration]: https://vector.dev/docs/administration/
[docs.configuration]: https://vector.dev/docs/setup/configuration/
[docs.deployment]: https://vector.dev/docs/setup/deployment/
[docs.roles.agent]: https://vector.dev/docs/setup/deployment/roles/agent/
[docs.roles.service]: https://vector.dev/docs/setup/deployment/roles/service/
[docs.sinks]: https://vector.dev/docs/reference/sinks/
[docs.sources]: https://vector.dev/docs/reference/sources/
[docs.transforms]: https://vector.dev/docs/reference/transforms/
[pages.index#correctness]: https://vector.dev/#correctness
[pages.index#performance]: https://vector.dev/#performance
[urls.default_configuration]: https://github.com/timberio/vector/blob/master/config/vector.toml
[urls.docker_alpine]: https://hub.docker.com/_/alpine
[urls.docker_debian]: https://hub.docker.com/_/debian
[urls.rust]: https://www.rust-lang.org/
[urls.vector_docker_source_files]: https://github.com/timberio/vector/tree/master/distribution/docker
[urls.vector_releases]: https://vector.dev/releases/latest
[urls.vector_repo]: https://github.com/timberio/vector
